import { RouterController, RouterHandlerType, RouterMapType } from '../types/TRouter';
export type BaseRouterUseType<T> = RouterController<T>[] | RouterController<T>;
export declare enum EVENTS {
    ROUTE_PROCESSED = 0,
    ALL_ROUTES_PROCESSED = 1
}
export default abstract class BaseRouter<T> {
    protected map: RouterMapType<T>;
    protected allRoutesLoaded: boolean;
    static separator: string;
    private __isExposed;
    private __totalOfRoutes;
    private __routesProccesed;
    private __eventListener;
    /**
     * defined method to lookup for a resource controller. MUST be implemented
     * @param receivedMethod
     * @param receivedPath
     */
    protected lookup(receivedMethod: string, receivedPath: string): Promise<RouterHandlerType<T>>;
    protected addEventListener(listenerHandler: any): void;
    private emit;
    private emitPartial;
    protected lookupInCustomRouter(eventMapLookupController: any): Promise<RouterHandlerType<T>>;
    protected getMapKey(route: Pick<RouterController<T>, 'path' | 'method'>, separator?: string): string;
    private useController;
    useAll(routes: RouterController<T>[], overrides?: Partial<RouterController<T>>): void;
    /**
     * Overloaded method.
     *
     * If args is type of [string,RouterController<T>] add a single controller for that path. Usually you call it when using the util createController.
     * if args is type of [RouterController<T>[]] add a bulk of paths.
     * @param args All arguments.
     */
    use(...args: [string, BaseRouterUseType<T>] | [BaseRouterUseType<T> | any] | [BaseRouterUseType<T>[] | any]): void;
    delete(awsPath: string): void;
    expose(): void;
    static errorToHttpError(e: any): {
        statusCode: any;
        body: any;
    };
}
